@@ -23,23 +23,30 @@ GISTORE_LOG_DIR     = "logs"
 GISTORE_LOCK_DIR    = "locks"
 
 class DefaultConfig(object):
-    sys_config_dir = os.environ.get('GISTORE_ETC') or '/etc/gistore'
+    if os.getuid() != 0:
+        sys_config_dir = os.path.expanduser('~/.gistore.d/etc')
+        tasks_dir = os.path.expanduser('~/.gistore.d/tasks')
+    else:
+        sys_config_dir = '/etc/gistore'
+        tasks_dir = '/etc/gistore/tasks'
     backend = "git"
+    backuphistory = 200
+
     root_only = False
     log_level = logging.INFO
     task = None
-    backup_history = 200
-    backup_copies  = 5
+    backuphistory = 200
+    backupcopies  = 5
     store_list = {'default': None }
 
 def initConfig():
-    task_dir = os.path.join(DefaultConfig.sys_config_dir, 'tasks')
-    if not os.path.exists(task_dir):
-        try:
-            os.makedirs(task_dir)
-        except OSError:
-            print >> sys.stderr, "no permisson to create dir: %s" % task_dir
-            return
+    for path in ( DefaultConfig.tasks_dir, DefaultConfig.sys_config_dir ):
+        if not os.path.exists( path ):
+            try:
+                os.makedirs( path )
+            except OSError:
+                print >> sys.stderr, "no permisson to create dir: %s" % path
+                return
 
     config_file = os.path.join(DefaultConfig.sys_config_dir, 'local_config.py')
     if os.path.exists(config_file):
@@ -74,8 +81,7 @@ DEFAULT_BACKUPS = []
 #import subprocess
 #proc = subprocess.Popen(
 #           ['python', '/opt/ossxp/bin/ossxp_pkgadmin.py', 'list_backup'],
-#           stdout=subprocess.PIPE, stderr=open('/dev/null', 'w'),
-#           close_fds=True )
+#           stdout=subprocess.PIPE, stderr=open('/dev/null', 'w') )
 #for line in proc.communicate()[0].splitlines():
 #    DEFAULT_BACKUPS.append(line.strip())
 
@@ -89,7 +95,8 @@ class Config(DefaultConfig):
 def getConfig():
     try:
         #Initial sys_config_dir if not exists.
-        if not os.path.exists(os.path.join(DefaultConfig.sys_config_dir, 'local_config.py')):
+        if not os.path.exists( os.path.join( DefaultConfig.sys_config_dir,
+                                             'local_config.py' ) ):
             initConfig()
 
         # load custom config file in /etc/gistore/local_config.py
