@@ -38,7 +38,8 @@ Options:
 
 Available command:
     list
-        List tasks linked to /etc/gistore/tasks/
+        List tasks linked to $HOME/.gistore.d/tasks or
+        /etc/gistore/tasks/ for root user.
 
     status [task or direcotry]
         Show backup repository's backup list and other status
@@ -46,15 +47,24 @@ Available command:
     init   [task or directory]
         Initial gistore backup repository
 
-    commit [task or direcotry]
-        Commit changes in backup repository. The following command run 
+    commit [-m message] [task or direcotry ...]
+        Commit changes in backup repository. The following command run
         in order:
           * mount
           * commit
           * umount
 
-    commit-all
+    commit-all [-m message]
         Commit changes in all backup tasks under /etc/gistore/tasks/
+
+    add path, ...
+        Add backup items.
+
+    rm path, ...
+        Remove backup items.
+
+    log [options...]
+        Show backup logs.
 '''
 
 import os
@@ -101,7 +111,6 @@ def get_log_level( level ):
 
 class GistoreCmd(object):
     opt_verbose = 4     # info
-    opt_message = None
 
     gistobj = None
 
@@ -139,12 +148,11 @@ class GistoreCmd(object):
     def do_list(args=[]):
         if not args:
             print "Task list:"
-            tasksdir = os.path.join(cfg.sys_config_dir, 'tasks')
-            if os.path.exists(tasksdir):
-                for t in sorted(os.listdir(tasksdir)):
+            if os.path.exists(cfg.tasks_dir):
+                for t in sorted(os.listdir(cfg.tasks_dir)):
                     if t.startswith("."):
                         continue
-                    dest = os.path.realpath(os.path.join(tasksdir,t))
+                    dest = os.path.realpath(os.path.join(cfg.tasks_dir,t))
                     print "    %-10s: %s" % (t, dest)
         else:
             GistoreCmd.do_status(args)
@@ -164,6 +172,38 @@ class GistoreCmd(object):
                 continue
 
 
+    @staticmethod
+    def do_add(args=[]):
+        if not args:
+            args = [None]
+        if len(args) == 1:
+            repos = None
+        else:
+            repos = args[0]
+            args = args[1:]
+        try:
+            GistoreCmd.gistobj = Gistore(repos)
+            GistoreCmd.gistobj.add(args)
+        except Exception, e:
+            logging.critical( get_exception(e) )
+
+
+    @staticmethod
+    def do_rm(args=[]):
+        if not args:
+            args = [None]
+        if len(args) == 1:
+            repos = None
+        else:
+            repos = args[0]
+            args = args[1:]
+        try:
+            GistoreCmd.gistobj = Gistore(repos)
+            GistoreCmd.gistobj.rm(args)
+        except Exception, e:
+            logging.critical( get_exception(e) )
+
+
     @staticmethod
     def do_umount(args=[]):
         if not args:
@@ -187,25 +227,36 @@ class GistoreCmd(object):
     @staticmethod
     def do_commit_all(args=[]):
         tasks = []
-        tasksdir = os.path.join(cfg.sys_config_dir, 'tasks')
-        if os.path.exists(tasksdir):
-            for t in sorted(os.listdir(tasksdir)):
+        if os.path.exists(cfg.tasks_dir):
+            for t in sorted(os.listdir(cfg.tasks_dir)):
                 if t.startswith("."):
                     continue
-                tasks.append(os.path.realpath(os.path.join(tasksdir,t)))
+                tasks.append(os.path.realpath(os.path.join(cfg.tasks_dir,t)))
         if tasks:
-            GistoreCmd.do_commit(tasks)
+            GistoreCmd.do_commit( args + tasks )
 
 
     @staticmethod
-    def do_commit(args=[]):
+    def do_commit(argv=[]):
+        commit_msg = None
+        try:
+            opts, args = getopt.getopt(
+                argv, "m:",
+                [ "message" ])
+        except getopt.error, msg:
+            return GistoreCmd.usage(1, msg)
+
+        for opt, arg in opts:
+            if opt in ('-m', '--message'):
+                commit_msg = arg
+
         if not args:
             args = [None]
         for repos in args:
             try:
                 GistoreCmd.gistobj = Gistore(repos)
                 GistoreCmd.gistobj.mount()
-                GistoreCmd.gistobj.commit( GistoreCmd.opt_message )
+                GistoreCmd.gistobj.commit( commit_msg )
                 GistoreCmd.gistobj.umount()
                 GistoreCmd.gistobj.post_check()
             except GistoreLockError, e:
@@ -221,6 +272,20 @@ class GistoreCmd(object):
                 continue
 
 
+    @staticmethod
+    def do_log(args=[]):
+        repos = None
+        if args and not args[0].startswith('-'):
+            repos = args[0]
+            args = args[1:]
+
+        try:
+            GistoreCmd.gistobj = Gistore(repos)
+            GistoreCmd.gistobj.log(args)
+        except Exception, e:
+            logging.critical( get_exception(e) )
+
+
     @staticmethod
     def sigint_handler(signum, frame):
         """Do umount and others cleanups if receive SIGINT.
@@ -254,7 +319,7 @@ class GistoreCmd(object):
         global cfg
         try:
             opts, args = getopt.getopt(
-                argv, "hvqm:",
+                argv, "hvq",
                 [ "help", "verbose", "quiet" ])
         except getopt.error, msg:
             return GistoreCmd.usage(1, msg)
@@ -272,8 +337,6 @@ class GistoreCmd(object):
                     GistoreCmd.opt_verbose = 0
                 else:
                     GistoreCmd.opt_verbose -= 1
-            elif opt in ('-m'):
-                GistoreCmd.opt_message = arg
 
         if GistoreCmd.opt_verbose is not None:
             cfg.log_level = GistoreCmd.opt_verbose
@@ -307,8 +370,8 @@ class GistoreCmd(object):
         elif command in ["ls", "dir"]:
             command = 'list'
 
-        # Parse command options, and args is command params.
-        args = GistoreCmd.parse_options(args[1:])
+        # Command args
+        args = args[1:]
 
         # Set logging basic config, to stderr
         logging.basicConfig( level=cfg.log_level,
@@ -325,7 +388,8 @@ class GistoreCmd(object):
             signal.signal(signal.SIGPIPE, GistoreCmd.sigint_handler)
             signal.signal(signal.SIGTERM, GistoreCmd.sigint_handler)
 
-            if 'do_'+command in filter(lambda n: n.startswith('do_'), dir(GistoreCmd)):
+            if 'do_'+command in filter( lambda n: n.startswith('do_'),
+                                        dir(GistoreCmd) ):
                 getattr(GistoreCmd, 'do_' + command)(args)
             else:
                 return GistoreCmd.usage(1, "Unknown command: %s" % command)
